from math import sqrt
import unittest

class Point(object):
    """Point class with public x and y attributes """
 
    def __init__(self, x=0, y=0):
        self.x = x
        self.y = y
 
    def dist(self, p):
        """return the Euclidian distance between self and p"""
        dx = self.x - p.x
        dy = self.y - p.y
        return sqrt(dx*dx + dy*dy)
 
    def reset(self):
        self.x = 0
        self.y = 0

    def __add__(self, p):
        """return a new point found by adding self and p. This method is called by e.g. p+q for points p and q"""
        return Point(self.x+p.x, self.y+p.y)
 
    def __repr__(self):
        """return a string representation of this point. This method is called by the repr() function, and
        also the str() function. It should produce a string that, when evaluated, returns a point with the 
        same data."""
        return 'Point(%d,%d)' % (self.x, self.y)
 
class TestPoint(unittest.TestCase):
 
    def test_dist(self):
        p1 = Point(1,2)
        p2 = Point(5,-1)
        self.assertEqual(p1.dist(p2), 5.0)
 
    def test_add(self):
        p1 = Point(1,2)
        p2 = Point(5,-10)
        sum = p1+p2
        self.assertEqual(sum.x, 6)
        self.assertEqual(sum.y, -8)

    def test_repr(self):
        p1 = Point(1,2)
        self.assertEqual(str(p1), 'Point(1,2)')
 
if __name__ == '__main__':
    unittest.main()
 